@@ -6,7 +6,7 @@ function(t,m,k,power=15,nstarts=1,itermax=100,total_iter=1000000){
   t00<-Sys.time()
   aaa<-.C("maximinSLHD",as.integer(m),as.integer(k),as.integer(t),as.integer(power),as.integer(nstarts),
           as.integer(itermax),as.integer(total_iter),design=integer(m*t*k),measure=double(1), 
-          temp0=double(1),ntotal=integer(1),PACKAGE="SLHD")
+          temp0=double(1),PACKAGE="SLHD")
   t01<-Sys.time()
   
   time_rec=t01-t00
@@ -25,7 +25,7 @@ function(t,m,k,power=15,nstarts=1,itermax=100,total_iter=1000000){
     SDslice[[i]]<-scaled_deisgn[((i-1)*m+1):(i*m),]
   }
   
-  val<-list(D=dd,DS=Dslice,standD=scaled_deisgn,standDS=SDslice,ntotal=aaa$ntotal,temp0=aaa$temp0,measure=aaa$measure,time_rec=time_rec)
+  val<-list(D=dd,DS=Dslice,standD=scaled_deisgn,standDS=SDslice,temp0=aaa$temp0,measure=aaa$measure,time_rec=time_rec)
   
   return(val)
 }
